/*global  $ noText yesText successMessage location enabledProducts genericError areYouSureTitle 
 areYouSureDeleteProduct deleteNumError continueText cancelText displayStatusModal noProductsFound hideLoading
showLoading displayModal
*/

var baseButton = $("<button/>")
        .addClass("col-xs-5 button btn button-yellow")
        .attr("data-dismiss", "modal");
var noButton = $(baseButton).clone()
        .text(noText).attr("id","no-button")
        .addClass("pull-right")
        .attr("data-dismiss", "modal").attr("data-user-response", "no");
var yesButton = $(baseButton).clone()
        .text(yesText)
        .attr("id", "yes-button")
        .attr("data-user-response", "yes");
var okButton = $(yesButton).clone()
        .text(continueText)
        .attr("id", "ok-button");
var cancelButton = $(noButton).clone()
        .text(cancelText)
        .attr("id", "cancel-button");

var products;
var normalizedProducts;


function GetRemoteIPs() {
    return $.ajax({
        url:"/config/scan/network",
        success: function(data, textStatus, jqXHR) {
            if (textStatus =="success" || textStatus =="notmodified") {
                normalizedProducts = normalizeProducts(data);
                products = data;
                displayProductModal(normalizedProducts);
            }
        },
        error: function(jqXHR, textStatus, errorThrown){
            if (errorThrown != "abort") {
                displayError({
                    type: "semanticErr",
                    reason: scanNetworkErrTitle,
                    message: scanNetworkErr
                });
            }
        },
        complete: function () {
            console.log("Were done here");
            hideLoading();
    

        }


    });
    
}


function maskSize() {
    return $("#mask-size").val();
}

function displayProductModal(products) {
    var productModal = buildProductModal(products);
    $(productModal).modal("show");
    
    
    
    
}

function sendAddProductsRequest(products) {
    sendRequest(products, {
        url: "/config/equipment/add",
        success: function() {
            displayStatusModal({
                title: successMessage,
                onClose: function() {
                    
                    location.reload();
                }});
        }
    });
}

function sendRequest(data, settings){
    var waitText = settings.waitText || "";
    var complete = settings.complete || function(){ hideLoading(); };
    var url = settings.url;
    var success = settings.success || function(data, textStatus, jqXHR) {};
    var method = settings.method || "POST";
    var error = settings.error || defaultSendRequestError;
    
    showLoading(waitText);

    return $.ajax({
        method: method,
        url: url,
        data: JSON.stringify(data),
        statusCode: settings.statusCode,
        success: function (data, textStatus, jqXHR) {
            success(data, textStatus, jqXHR);
        },
        error: function (jqXHR, textStatus, errorThrown) {
            hideLoading();
            error(jqXHR, textStatus, errorThrown);
        },
        complete: function() {
            complete();
        }
        
    }); 
}

function defaultSendRequestError(jqXHR, textStatus, errorThrown) {
        var error =  jqXHR.responseJSON;
        displayError(error);
    }


function normalizeProducts(products) {
    var normalizedProducts = [];
    for (var x in products) {
            normalizedProducts.push(products[x]);
    }
        
    return normalizedProducts;
    
}

function buildProductModal(products) {
    var productsContainer = $("#found-products");
    var productModal = $("#product-modal");
    var addButton = $(productModal).find("#add-selected");
    var page, row;
    var productsShown = 0;

    $(productsContainer).html('');
    for (var x in products) {
        if (isEnabledProduct(products[x])) {
            continue;   
        }
        if (productsShown % 21 == 0) {
            page = $("<div/>").addClass("product-page hidden");
            $(productsContainer).append(page);
        }

        if (productsShown == 0) {
            $(page).removeClass("hidden").addClass("current-page");
        }

        if (productsShown % 3 == 0) {
            row = $("<div/>").addClass("multi-select-row");
            $(page).append(row);
        }

        var product = buildProduct(x, products[x]);
        $(row).append(product);
        productsShown++;
    }

    if (productsShown == 0) {
        displayStatusModal({
            title: noProductsFound,
            show: false
        });
        return $("#status-modal");
    }
    $(addButton).unbind('click');
    $(addButton).bind('click', function() {
        var selectedProducts = getSelectedProducts(productModal);
        console.log(selectedProducts);
        sendAddProductsRequest(selectedProducts);
        $(productModal).modal("hide");
    });


    return $("#product-modal");
}


function buildProduct(index, product) {
    var id = "product-" + index;
    var option = $("<div/>").addClass("multi-select-option");
    var checkbox = $("<div/>").addClass("checkbox-custom");
    var input = $("<input/>").addClass("product-selected").attr("id", id).attr("name", id).attr("type", "checkbox").val("http://"+ product.IP);
    var label = $("<label/>").addClass("checkbox-custom-label").attr("for", id);
    var contents = $("<span/>").addClass("input-title");
    var productName = $("<div/>").addClass("product-name").append(product.DisplayName);
    var address = $("<div/>").addClass("address").append(product.IP);

    contents.append(productName,address);
    label.append(contents);
    checkbox.append(input, label);
    option.append(checkbox);

    return option;
    
}

function getSubComponents(index, product){
    var subcomponents = [];
    var components = product.DisplayName.split("/");
    
    for (var x in components) {
        var componentName = components[x];
        var name = product.Name.split("/")[x]; 
        var component = {
            Name: name,
            Port: product.Port,
            IP: product.IP,
            DisplayName: componentName,
            IsSubComponent: true,
            ProductID: index
        };
        subcomponents.push(component);
    }

    return subcomponents;
    
}



function isEnabledProduct(product) {
    for(var x in enabledProducts) {
        if (enabledProducts[x].IP == product.IP) {
            return true;
        }

    }
    return false;
}

function getSelectedProducts(modal) {
    var productInputs = $(modal).find(".product-selected:checked");
    var selectedProducts =[];
    console.log(selectedProducts, products, productInputs);
    for (var x = 0; x < productInputs.length; x++) {
        selectedProducts.push($(productInputs[x]).val());
    }

    return selectedProducts;
    
}



function displayError(error) {
    var title, body;

    if (error) {
        switch (error.type) {
        case "syntaxErr":
            title = "";
            body = genericError;
            break;
        case "semanticErr":
            title = error.reason;
            body = error.message;
            break;
        default:
            title = error.reason || "";
            body = genericError;
        }
    }

    displayModal({
        id: "#error-modal",
        bodyID: "#error-modal-body",
        titleID: "#error-modal-title",
        title:title,
        body:body
    });
    
}

function confirmDelete(product) {

    displayStatusModal({
        title: areYouSureTitle,
        body: areYouSureDeleteProduct,
        footer: $("<span/>").append($(noButton)).append($(yesButton))
    });
    
    $("#status-modal").modal("show");
    $(yesButton).click(function() {
        $("#status-modal").hide();
        

        $(product).remove();
        var ip = $(product).find(".product-ip").val();
        sendRequest(undefined, {
            method: "DELETE",
            url:"/config/equipment/" + ip,
            success: function () {
                showLoading();
                location.reload();
            },
            complete: function() {
                
            }
        });
    });
}









